# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.aws.v3 import credential_provider_pb2 as envoy_dot_extensions_dot_common_dot_aws_dot_v3_dot_credential__provider__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNenvoy/extensions/filters/http/aws_request_signing/v3/aws_request_signing.proto\x12\x34\x65nvoy.extensions.filters.http.aws_request_signing.v3\x1a\x38\x65nvoy/extensions/common/aws/v3/credential_provider.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc6\x05\n\x11\x41wsRequestSigning\x12\x1d\n\x0cservice_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0e\n\x06region\x18\x02 \x01(\t\x12\x14\n\x0chost_rewrite\x18\x03 \x01(\t\x12\x1c\n\x14use_unsigned_payload\x18\x04 \x01(\x08\x12\x44\n\x16match_excluded_headers\x18\x05 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12s\n\x11signing_algorithm\x18\x06 \x01(\x0e\x32X.envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.SigningAlgorithm\x12i\n\x0cquery_string\x18\x07 \x01(\x0b\x32S.envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning.QueryString\x12R\n\x13\x63redential_provider\x18\x08 \x01(\x0b\x32\x35.envoy.extensions.common.aws.v3.AwsCredentialProvider\x1aR\n\x0bQueryString\x12\x43\n\x0f\x65xpiration_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0f\xfa\x42\x0c\xaa\x01\t\"\x03\x08\x90\x1c\x32\x02\x08\x01\"1\n\x10SigningAlgorithm\x12\r\n\tAWS_SIGV4\x10\x00\x12\x0e\n\nAWS_SIGV4A\x10\x01:M\x9a\xc5\x88\x1eH\nFenvoy.config.filter.http.aws_request_signing.v2alpha.AwsRequestSigning\"\x9f\x01\n\x19\x41wsRequestSigningPerRoute\x12\x64\n\x13\x61ws_request_signing\x18\x01 \x01(\x0b\x32G.envoy.extensions.filters.http.aws_request_signing.v3.AwsRequestSigning\x12\x1c\n\x0bstat_prefix\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\xd9\x01\nBio.envoyproxy.envoy.extensions.filters.http.aws_request_signing.v3B\x16\x41wsRequestSigningProtoP\x01Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/aws_request_signing/v3;aws_request_signingv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.aws_request_signing.v3.aws_request_signing_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nBio.envoyproxy.envoy.extensions.filters.http.aws_request_signing.v3B\026AwsRequestSigningProtoP\001Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/aws_request_signing/v3;aws_request_signingv3\272\200\310\321\006\002\020\002'
  _AWSREQUESTSIGNING_QUERYSTRING.fields_by_name['expiration_time']._options = None
  _AWSREQUESTSIGNING_QUERYSTRING.fields_by_name['expiration_time']._serialized_options = b'\372B\014\252\001\t\"\003\010\220\0342\002\010\001'
  _AWSREQUESTSIGNING.fields_by_name['service_name']._options = None
  _AWSREQUESTSIGNING.fields_by_name['service_name']._serialized_options = b'\372B\004r\002\020\001'
  _AWSREQUESTSIGNING._options = None
  _AWSREQUESTSIGNING._serialized_options = b'\232\305\210\036H\nFenvoy.config.filter.http.aws_request_signing.v2alpha.AwsRequestSigning'
  _AWSREQUESTSIGNINGPERROUTE.fields_by_name['stat_prefix']._options = None
  _AWSREQUESTSIGNINGPERROUTE.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_AWSREQUESTSIGNING']._serialized_start=354
  _globals['_AWSREQUESTSIGNING']._serialized_end=1064
  _globals['_AWSREQUESTSIGNING_QUERYSTRING']._serialized_start=852
  _globals['_AWSREQUESTSIGNING_QUERYSTRING']._serialized_end=934
  _globals['_AWSREQUESTSIGNING_SIGNINGALGORITHM']._serialized_start=936
  _globals['_AWSREQUESTSIGNING_SIGNINGALGORITHM']._serialized_end=985
  _globals['_AWSREQUESTSIGNINGPERROUTE']._serialized_start=1067
  _globals['_AWSREQUESTSIGNINGPERROUTE']._serialized_end=1226
# @@protoc_insertion_point(module_scope)
