# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/proto_message_extraction/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/http/proto_message_extraction/v3/config.proto\x12\x39\x65nvoy.extensions.filters.http.proto_message_extraction.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\"\xe0\x04\n\x1cProtoMessageExtractionConfig\x12\x37\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x12)\n\x1fproto_descriptor_typed_metadata\x18\x02 \x01(\tH\x00\x12q\n\x04mode\x18\x03 \x01(\x0e\x32\x63.envoy.extensions.filters.http.proto_message_extraction.v3.ProtoMessageExtractionConfig.ExtractMode\x12\x8d\x01\n\x14\x65xtraction_by_method\x18\x04 \x03(\x0b\x32o.envoy.extensions.filters.http.proto_message_extraction.v3.ProtoMessageExtractionConfig.ExtractionByMethodEntry\x1a\x86\x01\n\x17\x45xtractionByMethodEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12Z\n\x05value\x18\x02 \x01(\x0b\x32K.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction:\x02\x38\x01\">\n\x0b\x45xtractMode\x12\x1b\n\x17\x45xtractMode_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x46IRST_AND_LAST\x10\x01\x42\x10\n\x0e\x64\x65scriptor_set\"\xce\x05\n\x10MethodExtraction\x12\x8e\x01\n\x1brequest_extraction_by_field\x18\x02 \x03(\x0b\x32i.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction.RequestExtractionByFieldEntry\x12\x90\x01\n\x1cresponse_extraction_by_field\x18\x03 \x03(\x0b\x32j.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction.ResponseExtractionByFieldEntry\x1a\x9d\x01\n\x1dRequestExtractionByFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12k\n\x05value\x18\x02 \x01(\x0e\x32\\.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction.ExtractDirective:\x02\x38\x01\x1a\x9e\x01\n\x1eResponseExtractionByFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12k\n\x05value\x18\x02 \x01(\x0e\x32\\.envoy.extensions.filters.http.proto_message_extraction.v3.MethodExtraction.ExtractDirective:\x02\x38\x01\"U\n\x10\x45xtractDirective\x12 \n\x1c\x45xtractDirective_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45XTRACT\x10\x01\x12\x12\n\x0e\x45XTRACT_REDACT\x10\x02\x42\xe5\x01\nGio.envoyproxy.envoy.extensions.filters.http.proto_message_extraction.v3B\x0b\x43onfigProtoP\x01Z{github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/proto_message_extraction/v3;proto_message_extractionv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.proto_message_extraction.v3.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nGio.envoyproxy.envoy.extensions.filters.http.proto_message_extraction.v3B\013ConfigProtoP\001Z{github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/proto_message_extraction/v3;proto_message_extractionv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTIONBYMETHODENTRY._options = None
  _PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTIONBYMETHODENTRY._serialized_options = b'8\001'
  _METHODEXTRACTION_REQUESTEXTRACTIONBYFIELDENTRY._options = None
  _METHODEXTRACTION_REQUESTEXTRACTIONBYFIELDENTRY._serialized_options = b'8\001'
  _METHODEXTRACTION_RESPONSEEXTRACTIONBYFIELDENTRY._options = None
  _METHODEXTRACTION_RESPONSEEXTRACTIONBYFIELDENTRY._serialized_options = b'8\001'
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG']._serialized_start=231
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG']._serialized_end=839
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTIONBYMETHODENTRY']._serialized_start=623
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTIONBYMETHODENTRY']._serialized_end=757
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTMODE']._serialized_start=759
  _globals['_PROTOMESSAGEEXTRACTIONCONFIG_EXTRACTMODE']._serialized_end=821
  _globals['_METHODEXTRACTION']._serialized_start=842
  _globals['_METHODEXTRACTION']._serialized_end=1560
  _globals['_METHODEXTRACTION_REQUESTEXTRACTIONBYFIELDENTRY']._serialized_start=1155
  _globals['_METHODEXTRACTION_REQUESTEXTRACTIONBYFIELDENTRY']._serialized_end=1312
  _globals['_METHODEXTRACTION_RESPONSEEXTRACTIONBYFIELDENTRY']._serialized_start=1315
  _globals['_METHODEXTRACTION_RESPONSEEXTRACTIONBYFIELDENTRY']._serialized_end=1473
  _globals['_METHODEXTRACTION_EXTRACTDIRECTIVE']._serialized_start=1475
  _globals['_METHODEXTRACTION_EXTRACTDIRECTIVE']._serialized_end=1560
# @@protoc_insertion_point(module_scope)
