# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/connect_grpc_bridge/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAenvoy/extensions/filters/http/connect_grpc_bridge/v3/config.proto\x12\x34\x65nvoy.extensions.filters.http.connect_grpc_bridge.v3\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\"\x0e\n\x0c\x46ilterConfigB\xd6\x01\nBio.envoyproxy.envoy.extensions.filters.http.connect_grpc_bridge.v3B\x0b\x43onfigProtoP\x01Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/connect_grpc_bridge/v3;connect_grpc_bridgev3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.connect_grpc_bridge.v3.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nBio.envoyproxy.envoy.extensions.filters.http.connect_grpc_bridge.v3B\013ConfigProtoP\001Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/connect_grpc_bridge/v3;connect_grpc_bridgev3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _globals['_FILTERCONFIG']._serialized_start=187
  _globals['_FILTERCONFIG']._serialized_end=201
# @@protoc_insertion_point(module_scope)
