# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/common/set_filter_state/v3/value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import substitution_format_string_pb2 as envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?envoy/extensions/filters/common/set_filter_state/v3/value.proto\x12\x33\x65nvoy.extensions.filters.common.set_filter_state.v3\x1a\x35\x65nvoy/config/core/v3/substitution_format_string.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x85\x03\n\x10\x46ilterStateValue\x12\x1d\n\nobject_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x13\n\x0b\x66\x61\x63tory_key\x18\x06 \x01(\t\x12G\n\rformat_string\x18\x02 \x01(\x0b\x32..envoy.config.core.v3.SubstitutionFormatStringH\x01\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12v\n\x14shared_with_upstream\x18\x04 \x01(\x0e\x32X.envoy.extensions.filters.common.set_filter_state.v3.FilterStateValue.SharedWithUpstream\x12\x15\n\rskip_if_empty\x18\x05 \x01(\x08\"8\n\x12SharedWithUpstream\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04ONCE\x10\x01\x12\x0e\n\nTRANSITIVE\x10\x02\x42\n\n\x03key\x12\x03\xf8\x42\x01\x42\x0c\n\x05value\x12\x03\xf8\x42\x01\x42\xc8\x01\nAio.envoyproxy.envoy.extensions.filters.common.set_filter_state.v3B\nValueProtoP\x01Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/set_filter_state/v3;set_filter_statev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.common.set_filter_state.v3.value_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.common.set_filter_state.v3B\nValueProtoP\001Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/common/set_filter_state/v3;set_filter_statev3\272\200\310\321\006\002\020\002'
  _FILTERSTATEVALUE.oneofs_by_name['key']._options = None
  _FILTERSTATEVALUE.oneofs_by_name['key']._serialized_options = b'\370B\001'
  _FILTERSTATEVALUE.oneofs_by_name['value']._options = None
  _FILTERSTATEVALUE.oneofs_by_name['value']._serialized_options = b'\370B\001'
  _FILTERSTATEVALUE.fields_by_name['object_key']._options = None
  _FILTERSTATEVALUE.fields_by_name['object_key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_FILTERSTATEVALUE']._serialized_start=232
  _globals['_FILTERSTATEVALUE']._serialized_end=621
  _globals['_FILTERSTATEVALUE_SHAREDWITHUPSTREAM']._serialized_start=539
  _globals['_FILTERSTATEVALUE_SHAREDWITHUPSTREAM']._serialized_end=595
# @@protoc_insertion_point(module_scope)
