# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/listener/http_inspector/v3/http_inspector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHenvoy/extensions/filters/listener/http_inspector/v3/http_inspector.proto\x12\x33\x65nvoy.extensions.filters.listener.http_inspector.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"T\n\rHttpInspector:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.listener.http_inspector.v2.HttpInspectorB\xce\x01\nAio.envoyproxy.envoy.extensions.filters.listener.http_inspector.v3B\x12HttpInspectorProtoP\x01Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/listener/http_inspector/v3;http_inspectorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.listener.http_inspector.v3.http_inspector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.listener.http_inspector.v3B\022HttpInspectorProtoP\001Zkgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/listener/http_inspector/v3;http_inspectorv3\272\200\310\321\006\002\020\002'
  _HTTPINSPECTOR._options = None
  _HTTPINSPECTOR._serialized_options = b'\232\305\210\036>\n<envoy.config.filter.listener.http_inspector.v2.HttpInspector'
  _globals['_HTTPINSPECTOR']._serialized_start=195
  _globals['_HTTPINSPECTOR']._serialized_end=279
# @@protoc_insertion_point(module_scope)
