# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/endpoint/load_report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/api/v2/endpoint/load_report.proto\x12\x15\x65nvoy.api.v2.endpoint\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf6\x02\n\x15UpstreamLocalityStats\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12!\n\x19total_successful_requests\x18\x02 \x01(\x04\x12\"\n\x1atotal_requests_in_progress\x18\x03 \x01(\x04\x12\x1c\n\x14total_error_requests\x18\x04 \x01(\x04\x12\x1d\n\x15total_issued_requests\x18\x08 \x01(\x04\x12I\n\x11load_metric_stats\x18\x05 \x03(\x0b\x32..envoy.api.v2.endpoint.EndpointLoadMetricStats\x12M\n\x17upstream_endpoint_stats\x18\x07 \x03(\x0b\x32,.envoy.api.v2.endpoint.UpstreamEndpointStats\x12\x10\n\x08priority\x18\x06 \x01(\r\"\xbe\x02\n\x15UpstreamEndpointStats\x12+\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12)\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12!\n\x19total_successful_requests\x18\x02 \x01(\x04\x12\"\n\x1atotal_requests_in_progress\x18\x03 \x01(\x04\x12\x1c\n\x14total_error_requests\x18\x04 \x01(\x04\x12\x1d\n\x15total_issued_requests\x18\x07 \x01(\x04\x12I\n\x11load_metric_stats\x18\x05 \x03(\x0b\x32..envoy.api.v2.endpoint.EndpointLoadMetricStats\"u\n\x17\x45ndpointLoadMetricStats\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12)\n!num_requests_finished_with_metric\x18\x02 \x01(\x04\x12\x1a\n\x12total_metric_value\x18\x03 \x01(\x01\"\x91\x03\n\x0c\x43lusterStats\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1c\n\x14\x63luster_service_name\x18\x06 \x01(\t\x12W\n\x17upstream_locality_stats\x18\x02 \x03(\x0b\x32,.envoy.api.v2.endpoint.UpstreamLocalityStatsB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x1e\n\x16total_dropped_requests\x18\x03 \x01(\x04\x12M\n\x10\x64ropped_requests\x18\x05 \x03(\x0b\x32\x33.envoy.api.v2.endpoint.ClusterStats.DroppedRequests\x12\x37\n\x14load_report_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a\x43\n\x0f\x44roppedRequests\x12\x19\n\x08\x63\x61tegory\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x15\n\rdropped_count\x18\x02 \x01(\x04\x42\x9e\x01\n#io.envoyproxy.envoy.api.v2.endpointB\x0fLoadReportProtoP\x01Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.config.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.endpoint.load_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.api.v2.endpointB\017LoadReportProtoP\001Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint\362\230\376\217\005\032\022\030envoy.config.endpoint.v3\272\200\310\321\006\002\020\001'
  _CLUSTERSTATS_DROPPEDREQUESTS.fields_by_name['category']._options = None
  _CLUSTERSTATS_DROPPEDREQUESTS.fields_by_name['category']._serialized_options = b'\372B\004r\002 \001'
  _CLUSTERSTATS.fields_by_name['cluster_name']._options = None
  _CLUSTERSTATS.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002 \001'
  _CLUSTERSTATS.fields_by_name['upstream_locality_stats']._options = None
  _CLUSTERSTATS.fields_by_name['upstream_locality_stats']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_UPSTREAMLOCALITYSTATS']._serialized_start=280
  _globals['_UPSTREAMLOCALITYSTATS']._serialized_end=654
  _globals['_UPSTREAMENDPOINTSTATS']._serialized_start=657
  _globals['_UPSTREAMENDPOINTSTATS']._serialized_end=975
  _globals['_ENDPOINTLOADMETRICSTATS']._serialized_start=977
  _globals['_ENDPOINTLOADMETRICSTATS']._serialized_end=1094
  _globals['_CLUSTERSTATS']._serialized_start=1097
  _globals['_CLUSTERSTATS']._serialized_end=1498
  _globals['_CLUSTERSTATS_DROPPEDREQUESTS']._serialized_start=1431
  _globals['_CLUSTERSTATS_DROPPEDREQUESTS']._serialized_end=1498
# @@protoc_insertion_point(module_scope)
