# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/core/v2alpha/health_check_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0envoy/data/core/v2alpha/health_check_event.proto\x12\x17\x65nvoy.data.core.v2alpha\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x81\x05\n\x10HealthCheckEvent\x12Q\n\x13health_checker_type\x18\x01 \x01(\x0e\x32*.envoy.data.core.v2alpha.HealthCheckerTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12(\n\x04host\x18\x02 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x1d\n\x0c\x63luster_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12S\n\x15\x65ject_unhealthy_event\x18\x04 \x01(\x0b\x32\x32.envoy.data.core.v2alpha.HealthCheckEjectUnhealthyH\x00\x12K\n\x11\x61\x64\x64_healthy_event\x18\x05 \x01(\x0b\x32..envoy.data.core.v2alpha.HealthCheckAddHealthyH\x00\x12Q\n\x1ahealth_check_failure_event\x18\x07 \x01(\x0b\x32+.envoy.data.core.v2alpha.HealthCheckFailureH\x00\x12M\n\x15\x64\x65graded_healthy_host\x18\x08 \x01(\x0b\x32,.envoy.data.core.v2alpha.DegradedHealthyHostH\x00\x12P\n\x17no_longer_degraded_host\x18\t \x01(\x0b\x32-.envoy.data.core.v2alpha.NoLongerDegradedHostH\x00\x12-\n\ttimestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"l\n\x19HealthCheckEjectUnhealthy\x12O\n\x0c\x66\x61ilure_type\x18\x01 \x01(\x0e\x32/.envoy.data.core.v2alpha.HealthCheckFailureTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\",\n\x15HealthCheckAddHealthy\x12\x13\n\x0b\x66irst_check\x18\x01 \x01(\x08\"z\n\x12HealthCheckFailure\x12O\n\x0c\x66\x61ilure_type\x18\x01 \x01(\x0e\x32/.envoy.data.core.v2alpha.HealthCheckFailureTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x13\n\x0b\x66irst_check\x18\x02 \x01(\x08\"\x15\n\x13\x44\x65gradedHealthyHost\"\x16\n\x14NoLongerDegradedHost*>\n\x16HealthCheckFailureType\x12\n\n\x06\x41\x43TIVE\x10\x00\x12\x0b\n\x07PASSIVE\x10\x01\x12\x0b\n\x07NETWORK\x10\x02*;\n\x11HealthCheckerType\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\x08\n\x04GRPC\x10\x02\x12\t\n\x05REDIS\x10\x03\x42\x88\x01\n%io.envoyproxy.envoy.data.core.v2alphaB\x15HealthCheckEventProtoP\x01Z>github.com/envoyproxy/go-control-plane/envoy/data/core/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.core.v2alpha.health_check_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.envoyproxy.envoy.data.core.v2alphaB\025HealthCheckEventProtoP\001Z>github.com/envoyproxy/go-control-plane/envoy/data/core/v2alpha\272\200\310\321\006\002\020\001'
  _HEALTHCHECKEVENT.oneofs_by_name['event']._options = None
  _HEALTHCHECKEVENT.oneofs_by_name['event']._serialized_options = b'\370B\001'
  _HEALTHCHECKEVENT.fields_by_name['health_checker_type']._options = None
  _HEALTHCHECKEVENT.fields_by_name['health_checker_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECKEVENT.fields_by_name['cluster_name']._options = None
  _HEALTHCHECKEVENT.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002 \001'
  _HEALTHCHECKEJECTUNHEALTHY.fields_by_name['failure_type']._options = None
  _HEALTHCHECKEJECTUNHEALTHY.fields_by_name['failure_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECKFAILURE.fields_by_name['failure_type']._options = None
  _HEALTHCHECKFAILURE.fields_by_name['failure_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_HEALTHCHECKFAILURETYPE']._serialized_start=1170
  _globals['_HEALTHCHECKFAILURETYPE']._serialized_end=1232
  _globals['_HEALTHCHECKERTYPE']._serialized_start=1234
  _globals['_HEALTHCHECKERTYPE']._serialized_end=1293
  _globals['_HEALTHCHECKEVENT']._serialized_start=200
  _globals['_HEALTHCHECKEVENT']._serialized_end=841
  _globals['_HEALTHCHECKEJECTUNHEALTHY']._serialized_start=843
  _globals['_HEALTHCHECKEJECTUNHEALTHY']._serialized_end=951
  _globals['_HEALTHCHECKADDHEALTHY']._serialized_start=953
  _globals['_HEALTHCHECKADDHEALTHY']._serialized_end=997
  _globals['_HEALTHCHECKFAILURE']._serialized_start=999
  _globals['_HEALTHCHECKFAILURE']._serialized_end=1121
  _globals['_DEGRADEDHEALTHYHOST']._serialized_start=1123
  _globals['_DEGRADEDHEALTHYHOST']._serialized_end=1144
  _globals['_NOLONGERDEGRADEDHOST']._serialized_start=1146
  _globals['_NOLONGERDEGRADEDHOST']._serialized_end=1168
# @@protoc_insertion_point(module_scope)
