# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.extensions.filters.network.thrift_proxy.v3 import route_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_thrift__proxy_dot_v3_dot_route__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCenvoy/extensions/filters/network/thrift_proxy/v3/thrift_proxy.proto\x12\x30\x65nvoy.extensions.filters.network.thrift_proxy.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1a(envoy/config/core/v3/config_source.proto\x1a<envoy/extensions/filters/network/thrift_proxy/v3/route.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"f\n\x04Trds\x12\x43\n\rconfig_source\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11route_config_name\x18\x02 \x01(\t\"\x94\x06\n\x0bThriftProxy\x12\\\n\ttransport\x18\x02 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x03 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12s\n\x0croute_config\x18\x04 \x01(\x0b\x32\x44.envoy.extensions.filters.network.thrift_proxy.v3.RouteConfigurationB\x17\xf2\x98\xfe\x8f\x05\x11\x12\x0froute_specifier\x12]\n\x04trds\x18\x08 \x01(\x0b\x32\x36.envoy.extensions.filters.network.thrift_proxy.v3.TrdsB\x17\xf2\x98\xfe\x8f\x05\x11\x12\x0froute_specifier\x12V\n\x0ethrift_filters\x18\x05 \x03(\x0b\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ThriftFilter\x12\x1b\n\x13payload_passthrough\x18\x06 \x01(\x08\x12\x41\n\x1bmax_requests_per_connection\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\naccess_log\x18\t \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12!\n\x19header_keys_preserve_case\x18\n \x01(\x08:D\x9a\xc5\x88\x1e?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProxy\"\xb7\x01\n\x0cThriftFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:E\x9a\xc5\x88\x1e@\n>envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\xa1\x02\n\x15ThriftProtocolOptions\x12\\\n\ttransport\x18\x01 \x01(\x0e\x32?.envoy.extensions.filters.network.thrift_proxy.v3.TransportTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12Z\n\x08protocol\x18\x02 \x01(\x0e\x32>.envoy.extensions.filters.network.thrift_proxy.v3.ProtocolTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:N\x9a\xc5\x88\x1eI\nGenvoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProtocolOptions*I\n\rTransportType\x12\x12\n\x0e\x41UTO_TRANSPORT\x10\x00\x12\n\n\x06\x46RAMED\x10\x01\x12\x0c\n\x08UNFRAMED\x10\x02\x12\n\n\x06HEADER\x10\x03*d\n\x0cProtocolType\x12\x11\n\rAUTO_PROTOCOL\x10\x00\x12\n\n\x06\x42INARY\x10\x01\x12\x0e\n\nLAX_BINARY\x10\x02\x12\x0b\n\x07\x43OMPACT\x10\x03\x12\x18\n\x07TWITTER\x10\x04\x1a\x0b\x08\x01\x8a\xf4\x9b\xb3\x05\x03\x33.0B\xc4\x01\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\x10ThriftProxyProtoP\x01Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/v3;thrift_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.thrift_proxy.v3.thrift_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\020ThriftProxyProtoP\001Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/v3;thrift_proxyv3\272\200\310\321\006\002\020\002'
  _PROTOCOLTYPE.values_by_name["TWITTER"]._options = None
  _PROTOCOLTYPE.values_by_name["TWITTER"]._serialized_options = b'\010\001\212\364\233\263\005\0033.0'
  _TRDS.fields_by_name['config_source']._options = None
  _TRDS.fields_by_name['config_source']._serialized_options = b'\372B\005\212\001\002\020\001'
  _THRIFTPROXY.fields_by_name['transport']._options = None
  _THRIFTPROXY.fields_by_name['transport']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROXY.fields_by_name['protocol']._options = None
  _THRIFTPROXY.fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROXY.fields_by_name['stat_prefix']._options = None
  _THRIFTPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _THRIFTPROXY.fields_by_name['route_config']._options = None
  _THRIFTPROXY.fields_by_name['route_config']._serialized_options = b'\362\230\376\217\005\021\022\017route_specifier'
  _THRIFTPROXY.fields_by_name['trds']._options = None
  _THRIFTPROXY.fields_by_name['trds']._serialized_options = b'\362\230\376\217\005\021\022\017route_specifier'
  _THRIFTPROXY._options = None
  _THRIFTPROXY._serialized_options = b'\232\305\210\036?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProxy'
  _THRIFTFILTER.fields_by_name['name']._options = None
  _THRIFTFILTER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _THRIFTFILTER._options = None
  _THRIFTFILTER._serialized_options = b'\232\305\210\036@\n>envoy.config.filter.network.thrift_proxy.v2alpha1.ThriftFilter'
  _THRIFTPROTOCOLOPTIONS.fields_by_name['transport']._options = None
  _THRIFTPROTOCOLOPTIONS.fields_by_name['transport']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROTOCOLOPTIONS.fields_by_name['protocol']._options = None
  _THRIFTPROTOCOLOPTIONS.fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _THRIFTPROTOCOLOPTIONS._options = None
  _THRIFTPROTOCOLOPTIONS._serialized_options = b'\232\305\210\036I\nGenvoy.config.filter.network.thrift_proxy.v2alpha1.ThriftProtocolOptions'
  _globals['_TRANSPORTTYPE']._serialized_start=1860
  _globals['_TRANSPORTTYPE']._serialized_end=1933
  _globals['_PROTOCOLTYPE']._serialized_start=1935
  _globals['_PROTOCOLTYPE']._serialized_end=2035
  _globals['_TRDS']._serialized_start=487
  _globals['_TRDS']._serialized_end=589
  _globals['_THRIFTPROXY']._serialized_start=592
  _globals['_THRIFTPROXY']._serialized_end=1380
  _globals['_THRIFTFILTER']._serialized_start=1383
  _globals['_THRIFTFILTER']._serialized_end=1566
  _globals['_THRIFTPROTOCOLOPTIONS']._serialized_start=1569
  _globals['_THRIFTPROTOCOLOPTIONS']._serialized_end=1858
# @@protoc_insertion_point(module_scope)
