# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_json_reverse_transcoder/v3/transcoder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNenvoy/extensions/filters/http/grpc_json_reverse_transcoder/v3/transcoder.proto\x12=envoy.extensions.filters.http.grpc_json_reverse_transcoder.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf8\x01\n\x19GrpcJsonReverseTranscoder\x12\x17\n\x0f\x64\x65scriptor_path\x18\x01 \x01(\t\x12\x19\n\x11\x64\x65scriptor_binary\x18\x02 \x01(\x0c\x12\x44\n\x15max_request_body_size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12\x45\n\x16max_response_body_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12\x1a\n\x12\x61pi_version_header\x18\x05 \x01(\tB\xee\x01\nKio.envoyproxy.envoy.extensions.filters.http.grpc_json_reverse_transcoder.v3B\x0fTranscoderProtoP\x01Z\x83\x01github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_json_reverse_transcoder/v3;grpc_json_reverse_transcoderv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.grpc_json_reverse_transcoder.v3.transcoder_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nKio.envoyproxy.envoy.extensions.filters.http.grpc_json_reverse_transcoder.v3B\017TranscoderProtoP\001Z\203\001github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_json_reverse_transcoder/v3;grpc_json_reverse_transcoderv3\272\200\310\321\006\002\020\002'
  _GRPCJSONREVERSETRANSCODER.fields_by_name['max_request_body_size']._options = None
  _GRPCJSONREVERSETRANSCODER.fields_by_name['max_request_body_size']._serialized_options = b'\372B\004*\002 \000'
  _GRPCJSONREVERSETRANSCODER.fields_by_name['max_response_body_size']._options = None
  _GRPCJSONREVERSETRANSCODER.fields_by_name['max_response_body_size']._serialized_options = b'\372B\004*\002 \000'
  _globals['_GRPCJSONREVERSETRANSCODER']._serialized_start=234
  _globals['_GRPCJSONREVERSETRANSCODER']._serialized_end=482
# @@protoc_insertion_point(module_scope)
