# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/generic_proxy/v3/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=envoy/extensions/filters/network/generic_proxy/v3/route.proto\x12\x31\x65nvoy.extensions.filters.network.generic_proxy.v3\x1a\x1fxds/annotations/v3/status.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"u\n\x0bVirtualHost\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x05hosts\x18\x02 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x36\n\x06routes\x18\x03 \x01(\x0b\x32\x1c.xds.type.matcher.v3.MatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\xb0\x01\n\x12RouteConfiguration\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x06routes\x18\x02 \x01(\x0b\x32\x1c.xds.type.matcher.v3.Matcher\x12U\n\rvirtual_hosts\x18\x03 \x03(\x0b\x32>.envoy.extensions.filters.network.generic_proxy.v3.VirtualHostB\xc9\x01\n?io.envoyproxy.envoy.extensions.filters.network.generic_proxy.v3B\nRouteProtoP\x01Zhgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/generic_proxy/v3;generic_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.generic_proxy.v3.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.extensions.filters.network.generic_proxy.v3B\nRouteProtoP\001Zhgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/generic_proxy/v3;generic_proxyv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _VIRTUALHOST.fields_by_name['name']._options = None
  _VIRTUALHOST.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _VIRTUALHOST.fields_by_name['hosts']._options = None
  _VIRTUALHOST.fields_by_name['hosts']._serialized_options = b'\372B\005\222\001\002\010\001'
  _VIRTUALHOST.fields_by_name['routes']._options = None
  _VIRTUALHOST.fields_by_name['routes']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTECONFIGURATION.fields_by_name['name']._options = None
  _ROUTECONFIGURATION.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_VIRTUALHOST']._serialized_start=240
  _globals['_VIRTUALHOST']._serialized_end=357
  _globals['_ROUTECONFIGURATION']._serialized_start=360
  _globals['_ROUTECONFIGURATION']._serialized_end=536
# @@protoc_insertion_point(module_scope)
