# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/cluster/v3/outlier_detection_event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3envoy/data/cluster/v3/outlier_detection_event.proto\x12\x15\x65nvoy.data.cluster.v3\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb6\x05\n\x15OutlierDetectionEvent\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32*.envoy.data.cluster.v3.OutlierEjectionTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x16secs_since_last_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1d\n\x0c\x63luster_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1d\n\x0cupstream_url\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x37\n\x06\x61\x63tion\x18\x06 \x01(\x0e\x32\x1d.envoy.data.cluster.v3.ActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rnum_ejections\x18\x07 \x01(\r\x12\x10\n\x08\x65nforced\x18\x08 \x01(\x08\x12R\n\x18\x65ject_success_rate_event\x18\t \x01(\x0b\x32..envoy.data.cluster.v3.OutlierEjectSuccessRateH\x00\x12Q\n\x17\x65ject_consecutive_event\x18\n \x01(\x0b\x32..envoy.data.cluster.v3.OutlierEjectConsecutiveH\x00\x12^\n\x1e\x65ject_failure_percentage_event\x18\x0b \x01(\x0b\x32\x34.envoy.data.cluster.v3.OutlierEjectFailurePercentageH\x00:7\x9a\xc5\x88\x1e\x32\n0envoy.data.cluster.v2alpha.OutlierDetectionEventB\x0c\n\x05\x65vent\x12\x03\xf8\x42\x01\"\xe1\x01\n\x17OutlierEjectSuccessRate\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12-\n\x1c\x63luster_average_success_rate\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64\x12\x38\n\'cluster_success_rate_ejection_threshold\x18\x03 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64:9\x9a\xc5\x88\x1e\x34\n2envoy.data.cluster.v2alpha.OutlierEjectSuccessRate\"T\n\x17OutlierEjectConsecutive:9\x9a\xc5\x88\x1e\x34\n2envoy.data.cluster.v2alpha.OutlierEjectConsecutive\"\x84\x01\n\x1dOutlierEjectFailurePercentage\x12\"\n\x11host_success_rate\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x64:?\x9a\xc5\x88\x1e:\n8envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage*\xdf\x01\n\x13OutlierEjectionType\x12\x13\n\x0f\x43ONSECUTIVE_5XX\x10\x00\x12\x1f\n\x1b\x43ONSECUTIVE_GATEWAY_FAILURE\x10\x01\x12\x10\n\x0cSUCCESS_RATE\x10\x02\x12$\n CONSECUTIVE_LOCAL_ORIGIN_FAILURE\x10\x03\x12\x1d\n\x19SUCCESS_RATE_LOCAL_ORIGIN\x10\x04\x12\x16\n\x12\x46\x41ILURE_PERCENTAGE\x10\x05\x12#\n\x1f\x46\x41ILURE_PERCENTAGE_LOCAL_ORIGIN\x10\x06* \n\x06\x41\x63tion\x12\t\n\x05\x45JECT\x10\x00\x12\x0b\n\x07UNEJECT\x10\x01\x42\x93\x01\n#io.envoyproxy.envoy.data.cluster.v3B\x1aOutlierDetectionEventProtoP\x01ZFgithub.com/envoyproxy/go-control-plane/envoy/data/cluster/v3;clusterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.cluster.v3.outlier_detection_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.envoyproxy.envoy.data.cluster.v3B\032OutlierDetectionEventProtoP\001ZFgithub.com/envoyproxy/go-control-plane/envoy/data/cluster/v3;clusterv3\272\200\310\321\006\002\020\002'
  _OUTLIERDETECTIONEVENT.oneofs_by_name['event']._options = None
  _OUTLIERDETECTIONEVENT.oneofs_by_name['event']._serialized_options = b'\370B\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['type']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002\020\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['upstream_url']._serialized_options = b'\372B\004r\002\020\001'
  _OUTLIERDETECTIONEVENT.fields_by_name['action']._options = None
  _OUTLIERDETECTIONEVENT.fields_by_name['action']._serialized_options = b'\372B\005\202\001\002\020\001'
  _OUTLIERDETECTIONEVENT._options = None
  _OUTLIERDETECTIONEVENT._serialized_options = b'\232\305\210\0362\n0envoy.data.cluster.v2alpha.OutlierDetectionEvent'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['host_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_average_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._options = None
  _OUTLIEREJECTSUCCESSRATE.fields_by_name['cluster_success_rate_ejection_threshold']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTSUCCESSRATE._options = None
  _OUTLIEREJECTSUCCESSRATE._serialized_options = b'\232\305\210\0364\n2envoy.data.cluster.v2alpha.OutlierEjectSuccessRate'
  _OUTLIEREJECTCONSECUTIVE._options = None
  _OUTLIEREJECTCONSECUTIVE._serialized_options = b'\232\305\210\0364\n2envoy.data.cluster.v2alpha.OutlierEjectConsecutive'
  _OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._options = None
  _OUTLIEREJECTFAILUREPERCENTAGE.fields_by_name['host_success_rate']._serialized_options = b'\372B\004*\002\030d'
  _OUTLIEREJECTFAILUREPERCENTAGE._options = None
  _OUTLIEREJECTFAILUREPERCENTAGE._serialized_options = b'\232\305\210\036:\n8envoy.data.cluster.v2alpha.OutlierEjectFailurePercentage'
  _globals['_OUTLIEREJECTIONTYPE']._serialized_start=1381
  _globals['_OUTLIEREJECTIONTYPE']._serialized_end=1604
  _globals['_ACTION']._serialized_start=1606
  _globals['_ACTION']._serialized_end=1638
  _globals['_OUTLIERDETECTIONEVENT']._serialized_start=235
  _globals['_OUTLIERDETECTIONEVENT']._serialized_end=929
  _globals['_OUTLIEREJECTSUCCESSRATE']._serialized_start=932
  _globals['_OUTLIEREJECTSUCCESSRATE']._serialized_end=1157
  _globals['_OUTLIEREJECTCONSECUTIVE']._serialized_start=1159
  _globals['_OUTLIEREJECTCONSECUTIVE']._serialized_end=1243
  _globals['_OUTLIEREJECTFAILUREPERCENTAGE']._serialized_start=1246
  _globals['_OUTLIEREJECTFAILUREPERCENTAGE']._serialized_end=1378
# @@protoc_insertion_point(module_scope)
