# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/http/custom_response/local_response_policy/v3/local_response_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import substitution_format_string_pb2 as envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZenvoy/extensions/http/custom_response/local_response_policy/v3/local_response_policy.proto\x12>envoy.extensions.http.custom_response.local_response_policy.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x35\x65nvoy/config/core/v3/substitution_format_string.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9f\x02\n\x13LocalResponsePolicy\x12.\n\x04\x62ody\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x43\n\x0b\x62ody_format\x18\x02 \x01(\x0b\x32..envoy.config.core.v3.SubstitutionFormatString\x12>\n\x0bstatus_code\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\xfa\x42\x08*\x06\x10\xd8\x04(\xc8\x01\x12S\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x42\xf9\x01\nLio.envoyproxy.envoy.extensions.http.custom_response.local_response_policy.v3B\x18LocalResponsePolicyProtoP\x01Z}github.com/envoyproxy/go-control-plane/envoy/extensions/http/custom_response/local_response_policy/v3;local_response_policyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.custom_response.local_response_policy.v3.local_response_policy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nLio.envoyproxy.envoy.extensions.http.custom_response.local_response_policy.v3B\030LocalResponsePolicyProtoP\001Z}github.com/envoyproxy/go-control-plane/envoy/extensions/http/custom_response/local_response_policy/v3;local_response_policyv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _LOCALRESPONSEPOLICY.fields_by_name['status_code']._options = None
  _LOCALRESPONSEPOLICY.fields_by_name['status_code']._serialized_options = b'\372B\010*\006\020\330\004(\310\001'
  _LOCALRESPONSEPOLICY.fields_by_name['response_headers_to_add']._options = None
  _LOCALRESPONSEPOLICY.fields_by_name['response_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _globals['_LOCALRESPONSEPOLICY']._serialized_start=368
  _globals['_LOCALRESPONSEPOLICY']._serialized_end=655
# @@protoc_insertion_point(module_scope)
