# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/accesslog/v2/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.data.accesslog.v2 import accesslog_pb2 as envoy_dot_data_dot_accesslog_dot_v2_dot_accesslog__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/service/accesslog/v2/als.proto\x12\x1a\x65nvoy.service.accesslog.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\'envoy/data/accesslog/v2/accesslog.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x1a\n\x18StreamAccessLogsResponse\"\xd9\x04\n\x17StreamAccessLogsMessage\x12R\n\nidentifier\x18\x01 \x01(\x0b\x32>.envoy.service.accesslog.v2.StreamAccessLogsMessage.Identifier\x12]\n\thttp_logs\x18\x02 \x01(\x0b\x32H.envoy.service.accesslog.v2.StreamAccessLogsMessage.HTTPAccessLogEntriesH\x00\x12[\n\x08tcp_logs\x18\x03 \x01(\x0b\x32G.envoy.service.accesslog.v2.StreamAccessLogsMessage.TCPAccessLogEntriesH\x00\x1aX\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x19\n\x08log_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a`\n\x14HTTPAccessLogEntries\x12H\n\tlog_entry\x18\x01 \x03(\x0b\x32+.envoy.data.accesslog.v2.HTTPAccessLogEntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a^\n\x13TCPAccessLogEntries\x12G\n\tlog_entry\x18\x01 \x03(\x0b\x32*.envoy.data.accesslog.v2.TCPAccessLogEntryB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x12\n\x0blog_entries\x12\x03\xf8\x42\x01\x32\x96\x01\n\x10\x41\x63\x63\x65ssLogService\x12\x81\x01\n\x10StreamAccessLogs\x12\x33.envoy.service.accesslog.v2.StreamAccessLogsMessage\x1a\x34.envoy.service.accesslog.v2.StreamAccessLogsResponse\"\x00(\x01\x42\x8d\x01\n(io.envoyproxy.envoy.service.accesslog.v2B\x08\x41lsProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/accesslog/v2;accesslogv2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.accesslog.v2.als_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.accesslog.v2B\010AlsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/accesslog/v2;accesslogv2\272\200\310\321\006\002\020\001'
  _STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['node']._options = None
  _STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['node']._serialized_options = b'\372B\005\212\001\002\020\001'
  _STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['log_name']._options = None
  _STREAMACCESSLOGSMESSAGE_IDENTIFIER.fields_by_name['log_name']._serialized_options = b'\372B\004r\002 \001'
  _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.fields_by_name['log_entry']._options = None
  _STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES.fields_by_name['log_entry']._serialized_options = b'\372B\005\222\001\002\010\001'
  _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.fields_by_name['log_entry']._options = None
  _STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES.fields_by_name['log_entry']._serialized_options = b'\372B\005\222\001\002\010\001'
  _STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']._options = None
  _STREAMACCESSLOGSMESSAGE.oneofs_by_name['log_entries']._serialized_options = b'\370B\001'
  _globals['_STREAMACCESSLOGSRESPONSE']._serialized_start=195
  _globals['_STREAMACCESSLOGSRESPONSE']._serialized_end=221
  _globals['_STREAMACCESSLOGSMESSAGE']._serialized_start=224
  _globals['_STREAMACCESSLOGSMESSAGE']._serialized_end=825
  _globals['_STREAMACCESSLOGSMESSAGE_IDENTIFIER']._serialized_start=523
  _globals['_STREAMACCESSLOGSMESSAGE_IDENTIFIER']._serialized_end=611
  _globals['_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES']._serialized_start=613
  _globals['_STREAMACCESSLOGSMESSAGE_HTTPACCESSLOGENTRIES']._serialized_end=709
  _globals['_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES']._serialized_start=711
  _globals['_STREAMACCESSLOGSMESSAGE_TCPACCESSLOGENTRIES']._serialized_end=805
  _globals['_ACCESSLOGSERVICE']._serialized_start=828
  _globals['_ACCESSLOGSERVICE']._serialized_end=978
# @@protoc_insertion_point(module_scope)
