# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/grpc_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/api/v2/core/grpc_service.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8f\x12\n\x0bGrpcService\x12>\n\nenvoy_grpc\x18\x01 \x01(\x0b\x32(.envoy.api.v2.core.GrpcService.EnvoyGrpcH\x00\x12@\n\x0bgoogle_grpc\x18\x02 \x01(\x0b\x32).envoy.api.v2.core.GrpcService.GoogleGrpcH\x00\x12*\n\x07timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x10initial_metadata\x18\x05 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\x1a*\n\tEnvoyGrpc\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x1a\xcc\x0f\n\nGoogleGrpc\x12\x1b\n\ntarget_uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12Y\n\x13\x63hannel_credentials\x18\x02 \x01(\x0b\x32<.envoy.api.v2.core.GrpcService.GoogleGrpc.ChannelCredentials\x12S\n\x10\x63\x61ll_credentials\x18\x03 \x03(\x0b\x32\x39.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials\x12\x1c\n\x0bstat_prefix\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12 \n\x18\x63redentials_factory_name\x18\x05 \x01(\t\x12\'\n\x06\x63onfig\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x1a\xb2\x01\n\x0eSslCredentials\x12\x31\n\nroot_certs\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12:\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x31\n\ncert_chain\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x1a\x18\n\x16GoogleLocalCredentials\x1a\x97\x02\n\x12\x43hannelCredentials\x12S\n\x0fssl_credentials\x18\x01 \x01(\x0b\x32\x38.envoy.api.v2.core.GrpcService.GoogleGrpc.SslCredentialsH\x00\x12\x30\n\x0egoogle_default\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12]\n\x11local_credentials\x18\x03 \x01(\x0b\x32@.envoy.api.v2.core.GrpcService.GoogleGrpc.GoogleLocalCredentialsH\x00\x42\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x1a\x9e\t\n\x0f\x43\x61llCredentials\x12\x16\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tH\x00\x12\x37\n\x15google_compute_engine\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x1e\n\x14google_refresh_token\x18\x03 \x01(\tH\x00\x12\x82\x01\n\x1aservice_account_jwt_access\x18\x04 \x01(\x0b\x32\\.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.ServiceAccountJWTAccessCredentialsH\x00\x12\x64\n\ngoogle_iam\x18\x05 \x01(\x0b\x32N.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.GoogleIAMCredentialsH\x00\x12n\n\x0b\x66rom_plugin\x18\x06 \x01(\x0b\x32W.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.MetadataCredentialsFromPluginH\x00\x12[\n\x0bsts_service\x18\x07 \x01(\x0b\x32\x44.envoy.api.v2.core.GrpcService.GoogleGrpc.CallCredentials.StsServiceH\x00\x1aV\n\"ServiceAccountJWTAccessCredentials\x12\x10\n\x08json_key\x18\x01 \x01(\t\x12\x1e\n\x16token_lifetime_seconds\x18\x02 \x01(\x04\x1aO\n\x14GoogleIAMCredentials\x12\x1b\n\x13\x61uthorization_token\x18\x01 \x01(\t\x12\x1a\n\x12\x61uthority_selector\x18\x02 \x01(\t\x1a\x99\x01\n\x1dMetadataCredentialsFromPlugin\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\x1a\xff\x01\n\nStsService\x12\"\n\x1atoken_exchange_service_uri\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12\x10\n\x08\x61udience\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x1c\n\x14requested_token_type\x18\x05 \x01(\t\x12#\n\x12subject_token_path\x18\x06 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12#\n\x12subject_token_type\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x18\n\x10\x61\x63tor_token_path\x18\x08 \x01(\t\x12\x18\n\x10\x61\x63tor_token_type\x18\t \x01(\tB\x1b\n\x14\x63redential_specifier\x12\x03\xf8\x42\x01\x42\x17\n\x10target_specifier\x12\x03\xf8\x42\x01J\x04\x08\x04\x10\x05\x42\x93\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x10GrpcServiceProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.grpc_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\020GrpcServiceProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _GRPCSERVICE_ENVOYGRPC.fields_by_name['cluster_name']._options = None
  _GRPCSERVICE_ENVOYGRPC.fields_by_name['cluster_name']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key']._options = None
  _GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS.fields_by_name['private_key']._serialized_options = b'\270\267\213\244\002\001'
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS.oneofs_by_name['credential_specifier']._serialized_options = b'\370B\001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN.fields_by_name['config']._serialized_options = b'\030\001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_path']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_path']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_type']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE.fields_by_name['subject_token_type']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']._options = None
  _GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS.oneofs_by_name['credential_specifier']._serialized_options = b'\370B\001'
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['target_uri']._options = None
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['target_uri']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['stat_prefix']._options = None
  _GRPCSERVICE_GOOGLEGRPC.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _GRPCSERVICE.oneofs_by_name['target_specifier']._options = None
  _GRPCSERVICE.oneofs_by_name['target_specifier']._serialized_options = b'\370B\001'
  _globals['_GRPCSERVICE']._serialized_start=330
  _globals['_GRPCSERVICE']._serialized_end=2649
  _globals['_GRPCSERVICE_ENVOYGRPC']._serialized_start=577
  _globals['_GRPCSERVICE_ENVOYGRPC']._serialized_end=619
  _globals['_GRPCSERVICE_GOOGLEGRPC']._serialized_start=622
  _globals['_GRPCSERVICE_GOOGLEGRPC']._serialized_end=2618
  _globals['_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS']._serialized_start=947
  _globals['_GRPCSERVICE_GOOGLEGRPC_SSLCREDENTIALS']._serialized_end=1125
  _globals['_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS']._serialized_start=1127
  _globals['_GRPCSERVICE_GOOGLEGRPC_GOOGLELOCALCREDENTIALS']._serialized_end=1151
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS']._serialized_start=1154
  _globals['_GRPCSERVICE_GOOGLEGRPC_CHANNELCREDENTIALS']._serialized_end=1433
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS']._serialized_start=1436
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS']._serialized_end=2618
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS']._serialized_start=2008
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_SERVICEACCOUNTJWTACCESSCREDENTIALS']._serialized_end=2094
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS']._serialized_start=2096
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_GOOGLEIAMCREDENTIALS']._serialized_end=2175
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN']._serialized_start=2178
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_METADATACREDENTIALSFROMPLUGIN']._serialized_end=2331
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE']._serialized_start=2334
  _globals['_GRPCSERVICE_GOOGLEGRPC_CALLCREDENTIALS_STSSERVICE']._serialized_end=2589
# @@protoc_insertion_point(module_scope)
