# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/common/aws/v3/credential_provider.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/extensions/common/aws/v3/credential_provider.proto\x12\x1e\x65nvoy.extensions.common.aws.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf9\x02\n\x15\x41wsCredentialProvider\x12{\n&assume_role_with_web_identity_provider\x18\x01 \x01(\x0b\x32K.envoy.extensions.common.aws.v3.AssumeRoleWithWebIdentityCredentialProvider\x12S\n\x11inline_credential\x18\x02 \x01(\x0b\x32\x38.envoy.extensions.common.aws.v3.InlineCredentialProvider\x12\x64\n\x19\x63redentials_file_provider\x18\x03 \x01(\x0b\x32\x41.envoy.extensions.common.aws.v3.CredentialsFileCredentialProvider\x12(\n custom_credential_provider_chain\x18\x04 \x01(\x08\"\x83\x01\n\x18InlineCredentialProvider\x12\x1e\n\raccess_key_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12(\n\x11secret_access_key\x18\x02 \x01(\tB\r\xfa\x42\x04r\x02\x10\x01\xb8\xb7\x8b\xa4\x02\x01\x12\x1d\n\rsession_token\x18\x03 \x01(\tB\x06\xb8\xb7\x8b\xa4\x02\x01\"\xb5\x01\n+AssumeRoleWithWebIdentityCredentialProvider\x12P\n\x1eweb_identity_token_data_source\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x19\n\x08role_arn\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x19\n\x11role_session_name\x18\x03 \x01(\t\"\x7f\n!CredentialsFileCredentialProvider\x12I\n\x17\x63redentials_data_source\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x0f\n\x07profile\x18\x02 \x01(\tB\x9e\x01\n,io.envoyproxy.envoy.extensions.common.aws.v3B\x17\x43redentialProviderProtoP\x01ZKgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/aws/v3;awsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.common.aws.v3.credential_provider_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,io.envoyproxy.envoy.extensions.common.aws.v3B\027CredentialProviderProtoP\001ZKgithub.com/envoyproxy/go-control-plane/envoy/extensions/common/aws/v3;awsv3\272\200\310\321\006\002\020\002'
  _INLINECREDENTIALPROVIDER.fields_by_name['access_key_id']._options = None
  _INLINECREDENTIALPROVIDER.fields_by_name['access_key_id']._serialized_options = b'\372B\004r\002\020\001'
  _INLINECREDENTIALPROVIDER.fields_by_name['secret_access_key']._options = None
  _INLINECREDENTIALPROVIDER.fields_by_name['secret_access_key']._serialized_options = b'\372B\004r\002\020\001\270\267\213\244\002\001'
  _INLINECREDENTIALPROVIDER.fields_by_name['session_token']._options = None
  _INLINECREDENTIALPROVIDER.fields_by_name['session_token']._serialized_options = b'\270\267\213\244\002\001'
  _ASSUMEROLEWITHWEBIDENTITYCREDENTIALPROVIDER.fields_by_name['web_identity_token_data_source']._options = None
  _ASSUMEROLEWITHWEBIDENTITYCREDENTIALPROVIDER.fields_by_name['web_identity_token_data_source']._serialized_options = b'\270\267\213\244\002\001'
  _ASSUMEROLEWITHWEBIDENTITYCREDENTIALPROVIDER.fields_by_name['role_arn']._options = None
  _ASSUMEROLEWITHWEBIDENTITYCREDENTIALPROVIDER.fields_by_name['role_arn']._serialized_options = b'\372B\004r\002\020\001'
  _CREDENTIALSFILECREDENTIALPROVIDER.fields_by_name['credentials_data_source']._options = None
  _CREDENTIALSFILECREDENTIALPROVIDER.fields_by_name['credentials_data_source']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_AWSCREDENTIALPROVIDER']._serialized_start=216
  _globals['_AWSCREDENTIALPROVIDER']._serialized_end=593
  _globals['_INLINECREDENTIALPROVIDER']._serialized_start=596
  _globals['_INLINECREDENTIALPROVIDER']._serialized_end=727
  _globals['_ASSUMEROLEWITHWEBIDENTITYCREDENTIALPROVIDER']._serialized_start=730
  _globals['_ASSUMEROLEWITHWEBIDENTITYCREDENTIALPROVIDER']._serialized_end=911
  _globals['_CREDENTIALSFILECREDENTIALPROVIDER']._serialized_start=913
  _globals['_CREDENTIALSFILECREDENTIALPROVIDER']._serialized_end=1040
# @@protoc_insertion_point(module_scope)
