# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/udp/udp_proxy/v3/udp_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.config.core.v3 import backoff_pb2 as envoy_dot_config_dot_core_dot_v3_dot_backoff__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import udp_socket_config_pb2 as envoy_dot_config_dot_core_dot_v3_dot_udp__socket__config__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9envoy/extensions/filters/udp/udp_proxy/v3/udp_proxy.proto\x12)envoy.extensions.filters.udp.udp_proxy.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1a\"envoy/config/core/v3/backoff.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a,envoy/config/core/v3/udp_socket_config.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbe\x11\n\x0eUdpProxyConfig\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12%\n\x07\x63luster\x18\x02 \x01(\tB\x12\x18\x01\xfa\x42\x04r\x02\x10\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12\x39\n\x07matcher\x18\t \x01(\x0b\x32\x1c.xds.type.matcher.v3.MatcherB\x08\xd2\xc6\xa4\xe1\x06\x02\x08\x01H\x00\x12/\n\x0cidle_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1b\n\x13use_original_src_ip\x18\x04 \x01(\x08\x12\x65\n\rhash_policies\x18\x05 \x03(\x0b\x32\x44.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.HashPolicyB\x08\xfa\x42\x05\x92\x01\x02\x10\x01\x12\x45\n\x16upstream_socket_config\x18\x06 \x01(\x0b\x32%.envoy.config.core.v3.UdpSocketConfig\x12%\n\x1duse_per_packet_load_balancing\x18\x07 \x01(\x08\x12\x38\n\naccess_log\x18\x08 \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12>\n\x10proxy_access_log\x18\n \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12`\n\x0fsession_filters\x18\x0b \x03(\x0b\x32G.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.SessionFilter\x12\x66\n\x10tunneling_config\x18\x0c \x01(\x0b\x32L.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.UdpTunnelingConfig\x12i\n\x12\x61\x63\x63\x65ss_log_options\x18\r \x01(\x0b\x32M.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.UdpAccessLogOptions\x1a[\n\nHashPolicy\x12\x1c\n\tsource_ip\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x16\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x42\x17\n\x10policy_specifier\x12\x03\xf8\x42\x01\x1a\xac\x01\n\rSessionFilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12G\n\x10\x63onfig_discovery\x18\x03 \x01(\x0b\x32+.envoy.config.core.v3.ExtensionConfigSourceH\x00\x42\r\n\x0b\x63onfig_type\x1a\xe2\x06\n\x12UdpTunnelingConfig\x12\x1b\n\nproxy_host\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x30\n\nproxy_port\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x0btarget_host\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12(\n\x13\x64\x65\x66\x61ult_target_port\x18\x04 \x01(\rB\x0b\xfa\x42\x08*\x06\x18\xff\xff\x03 \x00\x12\x10\n\x08use_post\x18\x05 \x01(\x08\x12\x11\n\tpost_path\x18\x06 \x01(\t\x12p\n\rretry_options\x18\x07 \x01(\x0b\x32Y.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.UdpTunnelingConfig.RetryOptions\x12J\n\x0eheaders_to_add\x18\x08 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12r\n\x0e\x62uffer_options\x18\t \x01(\x0b\x32Z.envoy.extensions.filters.udp.udp_proxy.v3.UdpProxyConfig.UdpTunnelingConfig.BufferOptions\x12\"\n\x1apropagate_response_headers\x18\n \x01(\x08\x12#\n\x1bpropagate_response_trailers\x18\x0b \x01(\x08\x1a\x87\x01\n\rBufferOptions\x12<\n\x16max_buffered_datagrams\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\x12max_buffered_bytes\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x1a\x8a\x01\n\x0cRetryOptions\x12:\n\x14max_connect_attempts\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12>\n\x0f\x62\x61\x63koff_options\x18\x02 \x01(\x0b\x32%.envoy.config.core.v3.BackoffStrategy\x1a\x8f\x01\n\x13UdpAccessLogOptions\x12J\n\x19\x61\x63\x63\x65ss_log_flush_interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x12,\n$flush_access_log_on_tunnel_connected\x18\x02 \x01(\x08:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfigB\x16\n\x0froute_specifier\x12\x03\xf8\x42\x01\x42\xb0\x01\n7io.envoyproxy.envoy.extensions.filters.udp.udp_proxy.v3B\rUdpProxyProtoP\x01Z\\github.com/envoyproxy/go-control-plane/envoy/extensions/filters/udp/udp_proxy/v3;udp_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.udp.udp_proxy.v3.udp_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.filters.udp.udp_proxy.v3B\rUdpProxyProtoP\001Z\\github.com/envoyproxy/go-control-plane/envoy/extensions/filters/udp/udp_proxy/v3;udp_proxyv3\272\200\310\321\006\002\020\002'
  _UDPPROXYCONFIG_HASHPOLICY.oneofs_by_name['policy_specifier']._options = None
  _UDPPROXYCONFIG_HASHPOLICY.oneofs_by_name['policy_specifier']._serialized_options = b'\370B\001'
  _UDPPROXYCONFIG_HASHPOLICY.fields_by_name['source_ip']._options = None
  _UDPPROXYCONFIG_HASHPOLICY.fields_by_name['source_ip']._serialized_options = b'\372B\004j\002\010\001'
  _UDPPROXYCONFIG_HASHPOLICY.fields_by_name['key']._options = None
  _UDPPROXYCONFIG_HASHPOLICY.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG_SESSIONFILTER.fields_by_name['name']._options = None
  _UDPPROXYCONFIG_SESSIONFILTER.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['proxy_host']._options = None
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['proxy_host']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['target_host']._options = None
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['target_host']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['default_target_port']._options = None
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['default_target_port']._serialized_options = b'\372B\010*\006\030\377\377\003 \000'
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['headers_to_add']._options = None
  _UDPPROXYCONFIG_UDPTUNNELINGCONFIG.fields_by_name['headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _UDPPROXYCONFIG_UDPACCESSLOGOPTIONS.fields_by_name['access_log_flush_interval']._options = None
  _UDPPROXYCONFIG_UDPACCESSLOGOPTIONS.fields_by_name['access_log_flush_interval']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _UDPPROXYCONFIG.oneofs_by_name['route_specifier']._options = None
  _UDPPROXYCONFIG.oneofs_by_name['route_specifier']._serialized_options = b'\370B\001'
  _UDPPROXYCONFIG.fields_by_name['stat_prefix']._options = None
  _UDPPROXYCONFIG.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _UDPPROXYCONFIG.fields_by_name['cluster']._options = None
  _UDPPROXYCONFIG.fields_by_name['cluster']._serialized_options = b'\030\001\372B\004r\002\020\001\222\307\206\330\004\0033.0'
  _UDPPROXYCONFIG.fields_by_name['matcher']._options = None
  _UDPPROXYCONFIG.fields_by_name['matcher']._serialized_options = b'\322\306\244\341\006\002\010\001'
  _UDPPROXYCONFIG.fields_by_name['hash_policies']._options = None
  _UDPPROXYCONFIG.fields_by_name['hash_policies']._serialized_options = b'\372B\005\222\001\002\020\001'
  _UDPPROXYCONFIG._options = None
  _UDPPROXYCONFIG._serialized_options = b'\232\305\210\036:\n8envoy.config.filter.udp.udp_proxy.v2alpha.UdpProxyConfig'
  _globals['_UDPPROXYCONFIG']._serialized_start=592
  _globals['_UDPPROXYCONFIG']._serialized_end=2830
  _globals['_UDPPROXYCONFIG_HASHPOLICY']._serialized_start=1460
  _globals['_UDPPROXYCONFIG_HASHPOLICY']._serialized_end=1551
  _globals['_UDPPROXYCONFIG_SESSIONFILTER']._serialized_start=1554
  _globals['_UDPPROXYCONFIG_SESSIONFILTER']._serialized_end=1726
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG']._serialized_start=1729
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG']._serialized_end=2595
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG_BUFFEROPTIONS']._serialized_start=2319
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG_BUFFEROPTIONS']._serialized_end=2454
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG_RETRYOPTIONS']._serialized_start=2457
  _globals['_UDPPROXYCONFIG_UDPTUNNELINGCONFIG_RETRYOPTIONS']._serialized_end=2595
  _globals['_UDPPROXYCONFIG_UDPACCESSLOGOPTIONS']._serialized_start=2598
  _globals['_UDPPROXYCONFIG_UDPACCESSLOGOPTIONS']._serialized_end=2741
# @@protoc_insertion_point(module_scope)
